DTI Playground
==============

DTI Playground is an integrated DWI processing software. 


DMRIPrep
~~~~~~~~~~

DMRIPrep is a pipelined quality control processing tool to make clean and reliable tensor images. 


DMRIAtlasBuilder
~~~~~~~~~~~~~~~~~

DMRIAtlasBuilder makes DTI atlas from multiple level of image hierarchy. 


DMRIAutotract
~~~~~~~~~~~~~~~

DMRIAutotract is a pipelined tractography software from generating streamlines to post processing with various techiques including automatic fiber classification using machine learning.


